==> spring-boot-ext-1.2.71-sources.jar: cn/com/duibaboot/ext/autoconfigure/perftest/jedis/PipelineMethodInterceptor.java <==
package cn.com.duibaboot.ext.autoconfigure.perftest.jedis;

import java.lang.reflect.Method;

import cn.com.duiba.boot.perftest.PerfTestContext;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.EnhancedInstance;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.InstanceMethodsAroundInterceptor;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.MethodInterceptResult;
import com.alibaba.ttl.TransmittableThreadLocal;
import com.google.common.base.MoreObjects;
import org.springframework.util.ReflectionUtils;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.PipelineBase;

/**
 * 拦截jedis操作，在方法执行前切换dbindex，执行后切换回
 */
public class PipelineMethodInterceptor implements InstanceMethodsAroundInterceptor {
    private static final Integer PERF_INDEX=1;
    private final TransmittableThreadLocal<Integer> perfMode = new TransmittableThreadLocal<>();

    @Override
    public void beforeMethod(EnhancedInstance objInst, Method method, Object[] allArguments,
                             Class<?>[] argumentsTypes, MethodInterceptResult result) throws Throwable {
        if (PerfTestContext.isCurrentInPerfTestMode()) {
            Integer state = MoreObjects.firstNonNull(perfMode.get(), 0);
            perfMode.set(++state);
            if (state > 1) return;
            PerfTestContext.debugInfo("RedisPipeline");
            PipelineBase jedis = (PipelineBase) objInst;//TODO 切换index

        }
    }

    @Override
    public Object afterMethod(EnhancedInstance objInst, Method method, Object[] allArguments,
                              Class<?>[] argumentsTypes, Object ret) throws Throwable {
        if (PerfTestContext.isCurrentInPerfTestMode()) {
            Integer state = perfMode.get();
            perfMode.set(--state);
            if (state == 0) {

                perfMode.remove();
            }
        }
        return ret;
    }

    @Override
    public void handleMethodException(EnhancedInstance objInst, Method method, Object[] allArguments,
                                      Class<?>[] argumentsTypes, Throwable t) {

    }
}

==> spring-boot-ext-1.2.164-sources.jar: cn/com/duibaboot/ext/autoconfigure/perftest/jedis/PipelineMethodInterceptor.java <==
package cn.com.duibaboot.ext.autoconfigure.perftest.jedis;

import java.lang.reflect.Method;

import cn.com.duiba.boot.perftest.PerfTestContext;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.InstanceMethodsAroundInterceptor;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.MethodInterceptResult;
import com.alibaba.ttl.TransmittableThreadLocal;
import com.google.common.base.MoreObjects;
import redis.clients.jedis.PipelineBase;

/**
 * 拦截jedis操作，在方法执行前切换dbindex，执行后切换回
 */
public class PipelineMethodInterceptor implements InstanceMethodsAroundInterceptor {
    private static final Integer PERF_INDEX=1;
    private final TransmittableThreadLocal<Integer> perfMode = new TransmittableThreadLocal<>();

    @Override
    public void beforeMethod(Object objInst, Method method, Object[] allArguments,
                             Class<?>[] argumentsTypes, MethodInterceptResult result) throws Throwable {
        if (PerfTestContext.isCurrentInPerfTestMode()) {
            Integer state = MoreObjects.firstNonNull(perfMode.get(), 0);
            perfMode.set(++state);
            if (state > 1) return;
            PerfTestContext.debugInfo("RedisPipeline");
            PipelineBase jedis = (PipelineBase) objInst;//TODO 切换index

        }
    }

    @Override
    public Object afterMethod(Object zuperCall, Object objInst, Method method, Object[] allArguments,
                              Class<?>[] argumentsTypes, Object ret) throws Throwable {
        if (PerfTestContext.isCurrentInPerfTestMode()) {
            Integer state = perfMode.get();
            perfMode.set(--state);
            if (state == 0) {

                perfMode.remove();
            }
        }
        return ret;
    }

    @Override
    public void handleMethodException(Object objInst, Method method, Object[] allArguments,
                                      Class<?>[] argumentsTypes, Throwable t) {

    }
}
